==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/PoleSlownikKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class PoleSlownikKey extends GenericDPSObject {
    /**
     * POLE_SLOWNIK.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * POLE_SLOWNIK.WARTOSC
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long wartosc;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return POLE_SLOWNIK.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * POLE_SLOWNIK.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return POLE_SLOWNIK.WARTOSC
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getWartosc() {
        return wartosc;
    }

    /**
     * POLE_SLOWNIK.WARTOSC
     *
     * @param wartosc
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setWartosc(Long wartosc) {
        this.wartosc = wartosc;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        PoleSlownikKey other = (PoleSlownikKey) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getWartosc() == null ? other.getWartosc() == null : this.getWartosc().equals(other.getWartosc()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getWartosc() == null) ? 0 : getWartosc().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", wartosc=").append(wartosc);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/PoleSlownikKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class PoleSlownikKey extends GenericDPSObject {
    /**
     * POLE_SLOWNIK.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * POLE_SLOWNIK.WARTOSC
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long wartosc;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return POLE_SLOWNIK.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * POLE_SLOWNIK.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return POLE_SLOWNIK.WARTOSC
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getWartosc() {
        return wartosc;
    }

    /**
     * POLE_SLOWNIK.WARTOSC
     *
     * @param wartosc
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setWartosc(Long wartosc) {
        this.wartosc = wartosc;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        PoleSlownikKey other = (PoleSlownikKey) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getWartosc() == null ? other.getWartosc() == null : this.getWartosc().equals(other.getWartosc()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getWartosc() == null) ? 0 : getWartosc().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", wartosc=").append(wartosc);
        sb.append("]");
        return sb.toString();
    }
}
